@@ -51,6 +51,26 @@ class MistralClientTestBase(base.MistralCLIAuth, base.MistralCLIAltAuth):
             'functionaltests/resources/v2/wf_delay_v2.yaml', os.getcwd()
         )
 
+        cls.wf_wrapping_wf = os.path.relpath(
+            'functionaltests/resources/v2/wf_wrapping_wf_v2.yaml', os.getcwd()
+        )
+        cls.top_level_wf = os.path.relpath(
+            'functionaltests/resources/v2/for_namespaces/top_level_wf.yaml',
+            os.getcwd()
+        )
+        cls.middle_wf = os.path.relpath(
+            'functionaltests/resources/v2/for_namespaces/middle_wf.yaml',
+            os.getcwd()
+        )
+        cls.lowest_level_wf = os.path.relpath(
+            'functionaltests/resources/v2/for_namespaces/lowest_level_wf.yaml',
+            os.getcwd()
+        )
+        cls.async_wf_def = os.path.relpath(
+            'functionaltests/resources/v2/async.yaml',
+            os.getcwd()
+        )
+
         cls.act_def = os.path.relpath(
             'functionaltests/resources/v2/action_v2.yaml', os.getcwd()
         )
@@ -91,20 +111,36 @@ class MistralClientTestBase(base.MistralCLIAuth, base.MistralCLIAltAuth):
         else:
             return self.mistral_alt_user(cmd, params)
 
-    def workbook_create(self, wb_def, admin=True):
+    def workbook_create(self, wb_def, namespace='', admin=True,
+                        scope='private'):
+
+        params = '{0}'.format(wb_def)
+
+        namespace_params = ''
+
+        if namespace:
+            namespace_params += ' --namespace {}'.format(namespace)
+
+        if scope == 'public':
+            params += ' --public'
+
+        params += namespace_params
+
         wb = self.mistral_cli(
             admin,
             'workbook-create',
-            params='{0}'.format(wb_def)
+            params=params
         )
 
         wb_name = self.get_field_value(wb, "Name")
 
+        wb_delete_params = wb_name + namespace_params
+
         self.addCleanup(
             self.mistral_cli,
             admin,
             'workbook-delete',
-            params=wb_name
+            params=wb_delete_params
         )
 
         self.addCleanup(
@@ -116,12 +152,16 @@ class MistralClientTestBase(base.MistralCLIAuth, base.MistralCLIAltAuth):
 
         return wb
 
-    def workflow_create(self, wf_def, admin=True, scope='private'):
+    def workflow_create(self, wf_def, namespace='', admin=True,
+                        scope='private'):
         params = '{0}'.format(wf_def)
 
         if scope == 'public':
             params += ' --public'
 
+        if namespace:
+            params += " --namespace " + namespace
+
         wf = self.mistral_cli(
             admin,
             'workflow-create',
@@ -140,7 +180,7 @@ class MistralClientTestBase(base.MistralCLIAuth, base.MistralCLIAltAuth):
 
     def workflow_member_create(self, wf_id):
         cmd_param = (
-            '%s workflow %s' % (wf_id, self.get_project_id("demo"))
+            '%s workflow %s' % (wf_id, self.get_project_id("alt_demo"))
         )
         member = self.mistral_admin("member-create", params=cmd_param)
 
@@ -198,6 +238,21 @@ class MistralClientTestBase(base.MistralCLIAuth, base.MistralCLIAltAuth):
 
         return trigger
 
+    def event_trigger_create(self, name, wf_id, exchange,
+                             topic, event, wf_input, admin=True):
+
+        trigger = self.mistral_cli(
+            admin,
+            'event-trigger-create',
+            params=' '.join((name, wf_id, exchange, topic, event, wf_input)))
+        ev_tr_id = self.get_field_value(trigger, 'ID')
+        self.addCleanup(self.mistral_cli,
+                        admin,
+                        'event-trigger-delete',
+                        params=ev_tr_id)
+
+        return trigger
+
     def execution_create(self, params, admin=True):
         ex = self.mistral_cli(admin, 'execution-create', params=params)
         exec_id = self.get_field_value(ex, 'ID')
@@ -206,7 +261,7 @@ class MistralClientTestBase(base.MistralCLIAuth, base.MistralCLIAltAuth):
             self.mistral_cli,
             admin,
             'execution-delete',
-            params=exec_id
+            params="{} --force".format(exec_id)
         )
 
         return ex
